pro plot_EC_Earth3_cmip6_globalmean

; Program to plot atm global mean 
; Note the number of ensembles for EC-Earth historical+ssp2-4.5 runs 
; does not follow the realization number 
;--------------------------------------------------------------------
anomaly='yes'
var='tas'
nave=30

title1='TAS'
realm='Amon'

modelid='EC-Earth3'
expid='historical+SSP2-4.5'
nens=24
year1=1960
year2=2029
nyear=year2-year1+1
ntime=(year2-year1+1)*12
  
; ERA-Interim reanalysis data
rea_id='ERA-I'
y1_rea=1979
y2_rea=2018
ny_rea=y2_rea-y1_rea+1
nt_rea=ny_rea*12

; plot
psfile='tas_EC-Earth_CMIP6_ens_anomaly_ann.ps'
set_plot,'ps'
device,bits=24,file=psfile
device,xsize=18,ysize=25
;device,xsize=25,ysize=18
device,xoffset=2,yoffset=2.5
device,/color
!p.multi=[0,1,3,0,0] 

loadct,12

yrange=[-1.5,1.5]
area='gm'
title='Global '

; Read in EC-Earth3 global mean annual averaged tas
Z_cmip=fltarr(nyear,nens)
Z_ensm=fltarr(nyear)
Z_dcpp=fltarr(nyear)
for iens=0, nens-1 do begin
  if (iens lt 9) then variant='ens'+string(iens+1,'(i1.1)')
  if (iens ge 9) then variant='ens'+string(iens+1,'(i2.2)')
  infile='tas_gm_Amon_EC-Earth3_hist+ssp2_'+variant+'_1960-2029_ann.nc'
  ;print,'infile=',infile

  cdfid = NCDF_OPEN( infile ) 
  ncdf_varget, cdfid, var, read_in
  NCDF_CLOSE,  cdfid
  ;print,var,min(read_in),max(read_in)

  Z_cmip(*,iens)=read_in(0,0,*)
  Z_ensm(*)=Z_ensm(*)+read_in(0,0,*)/nens
endfor
; Mean of five selected members 
Z_dcpp(*)=(Z_cmip(*,1)+Z_cmip(*,2)+Z_cmip(*,4)+Z_cmip(*,7)+Z_cmip(*,17))/5.

; Read in monthly reanalysis
Z_ream=fltarr(ny_rea)
infile='tas_gm_Amon_ERA-I_reanalysis_197901-201812.nc'
;print,'infile=',infile
cdfid = NCDF_OPEN( infile )
ncdf_varget, cdfid, var, read_in
ncdf_close,  cdfid
;print,var,min(read_in),max(read_in)

; get annual average
for iy=0, ny_rea-1 do for im=0, 11 do Z_ream(iy)=Z_ream(iy)+read_in(0,0,im+iy*12)/12.

Zcl_rea=0.
ymean1=1997
ymean2=2016
ymean=ymean2-ymean1+1
for iy=ymean1, ymean2 do Zcl_rea=Zcl_rea+Z_ream(iy-ymean1)/ymean

; anomaly wrt ymean2-ymean1
if (anomaly eq 'yes') then begin
  for iy=year1-year1, year2-year1 do begin
    Z_ensm(iy)=Z_ensm(iy)-Zcl_rea
    Z_cmip(iy,*)=Z_cmip(iy,*)-Zcl_rea
    Z_dcpp(iy)=Z_dcpp(iy)-Zcl_rea
  endfor
  for iy=y1_rea-y1_rea, y2_rea-y1_rea do begin
    Z_ream(iy)=Z_ream(iy)-Zcl_rea
  endfor
endif
;print,area,' climat-CMIP:',min(Z_cl),max(Z_cl),' climat-Reanal:',min(Z_reac),max(Z_reac)

; plot time series

header=title+' '+title1
if (anomaly eq 'yes') then header=header+' bias wrt '+rea_id+' '+string(ymean1,'(i4)')+'-'+string(ymean2,'(i4)')
unit=' (C)'

xmin=year1
xmax=year2

plot,[xmin,xmax],[0.,0.],title=header, charsize=1.5, $
       xstyle=1,xrange=[xmin,xmax],xtitle='Time (month)', $
       ystyle=1,yrange=yrange,ytitle=var+unit

for iens= nens-1, 0, -1 do begin
  if (iens eq 0 ) then lcolor=red() else lcolor=fsc_color('gray')
  if (iens eq 4 or iens eq 2 or iens eq 7 or iens eq 17 )  then lcolor=magenta() 
  if (iens eq 0 ) then thick=3. else thick=1.

  x=indgen(nyear)+year1
  y=Z_cmip(*,iens)
  oplot,x,y,color=lcolor,thick=thick

  ;dx=(xmax-xmin)/5.
endfor
x=indgen(nyear)+year1
y=Z_ensm(*)
dy=(yrange(1)-yrange(0))/20.
oplot,x,y,color=black(),thick=7.  
xyouts,xmin+4.,yrange(1)-1.5*dy,'Hist.+SSP2-4.5 (all members)',color=black(),charsize=1.0
y=Z_dcpp(*)
oplot,x,y,color=magenta(),thick=5.
print,area,' CMIP: ',min(Z_cmip),max(Z_cmip), ' esnmean: ',min(Z_ensm),max(Z_ensm)
xyouts,xmin+4.,yrange(1)-3.0*dy,'FREE (5 members)',color=magenta(),charsize=1.0
xyouts,xmin+4.,yrange(1)-4.5*dy,'FREE1 (r5i1p1f1)',color=red(),charsize=1.0

device,/close_file
print,'psfile: ',psfile

end

